//--------------------------------------------------------------
// File     : main.c
// Datum    : 26.11.2013
// Version  : 1.1
// Autor    : UB
// EMail    : mc-4u(@)t-online.de
// Web      : www.mikrocontroller-4u.de
// CPU      : STM32F429
// IDE      : CooCox CoIDE 1.7.4
// GCC      : 4.7 2012q4
// Module   : CMSIS_BOOT, M4_CMSIS_CORE
// Funktion : Demo der DMA2D-Graphic-Lib
// Hinweis  : Diese zwei Files muessen auf 8MHz stehen
//              "cmsis_boot/stm32f4xx.h"
//              "cmsis_boot/system_stm32f4xx.c"
// In Configuration diese Define hinzufgen :
// "STM32F429_439xx" , "__ASSEMBLY__" , "USE_STDPERIPH_DRIVER"
//--------------------------------------------------------------

#include "main.h"
#include "stm32_ub_lcd_ili9341.h"
#include "stm32_ub_graphic2d.h"
#include <stdlib.h>



int main(void)
{
	uint16_t x1,y1,x2,y2,r1,r2,c;
	uint32_t n,m;
	DMA2D_Koord koord;

  SystemInit(); // Quarz Einstellungen aktivieren

  UB_LCD_Init();
  UB_LCD_LayerInit_Fullscreen();

  // auf Vordergrund schalten
  UB_LCD_SetLayer_2();

  while(1)
  {
	  //-------------------------------
	  // 1.) 10.000 Kreise zeichnen
	  //-------------------------------
	  for(n=0;n<10000;n++) {
	    x1=rand() % (LCD_MAXX);
	    y1=rand() % (LCD_MAXY);
	    r1=rand() % (30);
	    c=rand() % (65535);
	    UB_Graphic2D_DrawFullCircleDMA(x1,y1,r1,c);
	  }
	  // kleine Pause
	  for(n=0;n<30000000;n++);
	  //-------------------------------
	  // 2.) 10.000 Rechtecke zeichnen
	  //-------------------------------
	  for(n=0;n<10000;n++) {
	    x1=rand() % (LCD_MAXX);
	    y1=rand() % (LCD_MAXY);
	    x2=rand() % (LCD_MAXX);
	    y2=rand() % (LCD_MAXY);
	    c=rand() % (65535);
	    UB_Graphic2D_DrawFullRectDMA(x1,y1,x2,y2,c);
	  }
	  // kleine Pause
	  for(n=0;n<30000000;n++);
	  //-------------------------------
	  // 3.) bewegter Kreis
	  //-------------------------------
	  r1=0;r2=0;
	  x1=111;y1=111;
	  for(n=0;n<5000;n++) {
		  UB_Graphic2D_ClearSreenDMA(RGB_COL_GREEN);
		  UB_Graphic2D_DrawFullCircleDMA(x1,y1,60,RGB_COL_RED);
		  UB_LCD_Refresh();
		  if(r1==0) {
		    x1++;
		    if(x1>240-60) r1=1-r1;
		  }
		  else {
			x1--;
			if(x1<60) r1=1-r1;
		  }
		  if(r2==0) {
		    y1++;
		    if(y1>320-60) r2=1-r2;
		  }
		  else {
			y1--;
			if(y1<60) r2=1-r2;
		  }
	  }
	  // kleine Pause
	  for(n=0;n<30000000;n++);
	  //-------------------------------
	  // 4.) bewegtes Teil Bild aus einem Image
	  //-------------------------------
	  r1=0;r2=0;
	  x1=111;y1=111;
	  // Koordinaten (nur ein Teilbild von 100x80 Pixel)
	  koord.source_xp=20;
	  koord.source_yp=20;
	  koord.source_w=100;
	  koord.source_h=80;
	  koord.dest_xp=x1;
	  koord.dest_yp=y1;
	  for(n=0;n<5000;n++) {
		  UB_Graphic2D_ClearSreenDMA(RGB_COL_GREEN);
		  UB_Graphic2D_CopyImgDMA(&Emo2_Image,koord);
		  for(m=0;m<500;m++); // pause (sonst flicker)
		  UB_LCD_Refresh();
		  for(m=0;m<100000;m++); // pause (sonst zu schnell)
		  if(r1==0) {
		    x1++;
		    if(x1>240-101) r1=1-r1;
		  }
		  else {
			x1--;
			if(x1<2) r1=1-r1;
		  }
		  if(r2==0) {
		    y1++;
		    if(y1>320-81) r2=1-r2;
		  }
		  else {
			y1--;
			if(y1<2) r2=1-r2;
		  }
		  koord.dest_xp=x1;
		  koord.dest_yp=y1;
	  }
	  //-------------------------------
	  // 5.) Ende
	  //-------------------------------

	  // wieder auf Vordergrund schalten
	  UB_LCD_SetLayer_2();
	  UB_LCD_SetTransparency(255);
  }
}

